@@ -4,10 +4,11 @@
 import { expect, galata, test } from '@jupyterlab/galata';
 import path from 'path';
 import {
+  filterContent,
+  freeezeKernelIds,
   generateArrow,
   positionMouse,
-  positionMouseOver,
-  setSidebarWidth
+  positionMouseOver
 } from './utils';
 
 test.use({
@@ -18,7 +19,7 @@ test.use({
 
 test.describe('General', () => {
   test('Welcome', async ({ page }) => {
-    await galata.Mock.freezeContentLastModified(page);
+    await galata.Mock.freezeContentLastModified(page, filterContent);
     await page.goto();
     await page.addStyleTag({
       content: `.jp-LabShell.jp-mod-devMode {
@@ -26,7 +27,7 @@ test.describe('General', () => {
       }`
     });
 
-    await setSidebarWidth(page);
+    await page.sidebar.setWidth();
 
     // README.md in preview
     await page.click('text=README.md', {
@@ -56,9 +57,8 @@ test.describe('General', () => {
     await page.click('div[role="main"] >> text=Lorenz.ipynb');
 
     await page.notebook.run();
-    await page.notebook.selectCells(0);
 
-    const cell = await page.$(
+    const cell = page.locator(
       '[aria-label="Code Cell Content with Output"] >> text=interactive'
     );
     await cell.click();
@@ -66,7 +66,9 @@ test.describe('General', () => {
     await page.click('text=Create New View for Cell Output');
 
     // Emulate drag and drop
-    const viewerHandle = await page.$('div[role="main"] >> text=lorenz.py');
+    const viewerHandle = page.locator(
+      '.lm-TabBar-tabLabel:text-is("lorenz.py")'
+    );
     await viewerHandle.click();
     const viewerBBox = await viewerHandle.boundingBox();
 
@@ -78,11 +80,17 @@ test.describe('General', () => {
     await page.mouse.move(viewerBBox.x + 0.5 * viewerBBox.width, 600);
     await page.mouse.up();
 
+    // wait for the debugger bug icon to settle
+    const panel = (await page.activity.getPanelLocator('Lorenz.ipynb'))!;
+    await panel
+      .locator('.jp-DebuggerBugButton[aria-disabled="false"]')
+      .waitFor();
+
     expect(await page.screenshot()).toMatchSnapshot('jupyterlab.png');
   });
 
   test('Left Sidebar', async ({ page }) => {
-    await galata.Mock.freezeContentLastModified(page);
+    await galata.Mock.freezeContentLastModified(page, filterContent);
     await page.goto();
     await page.addStyleTag({
       content: `.jp-LabShell.jp-mod-devMode {
@@ -90,11 +98,11 @@ test.describe('General', () => {
       }`
     });
 
-    await setSidebarWidth(page);
+    await page.sidebar.setWidth();
 
     await page.dblclick('[aria-label="File Browser Section"] >> text=data');
     // Wait for the `data` folder to load to have something to blur
-    await page.waitForSelector('text=1024px');
+    await page.locator('text=1024px').waitFor();
 
     await page.evaluate(() => {
       (document.activeElement as HTMLElement).blur();
@@ -115,7 +123,7 @@ test.describe('General', () => {
 
     await page.notebook.createNew();
     await page.click('[title="Property Inspector"]');
-    await setSidebarWidth(page, 251, 'right');
+    await page.sidebar.setWidth(251, 'right');
 
     expect(
       await page.screenshot({
@@ -202,7 +210,7 @@ test.describe('General', () => {
     await expect(
       page.locator('.jp-ActiveCellTool .jp-InputPrompt')
     ).toHaveClass(/lm-mod-hidden/);
-    await (await page.notebook.getCellInput(1))?.click();
+    await (await page.notebook.getCellInputLocator(1))?.click();
     await page.keyboard.type(' content');
     await expect(
       page.locator('.jp-ActiveCellTool .jp-ActiveCellTool-Content pre')
@@ -262,9 +270,10 @@ test.describe('General', () => {
 
     await page.click('text=File');
     await page.mouse.move(70, 40);
-    const fileMenuNewItem = await page.waitForSelector(
-      '.lm-Menu ul[role="menu"] >> text=New'
-    );
+    const fileMenuNewItem = page
+      .locator('.lm-Menu ul[role="menu"]')
+      .getByText('New', { exact: true });
+    await fileMenuNewItem.waitFor();
     await fileMenuNewItem.click();
 
     // Inject mouse
@@ -295,7 +304,7 @@ test.describe('General', () => {
       }`
     });
 
-    await setSidebarWidth(page);
+    await page.sidebar.setWidth();
 
     await page.dblclick(
       '[aria-label="File Browser Section"] >> text=notebooks'
@@ -304,14 +313,14 @@ test.describe('General', () => {
     await page.click('text=Lorenz.ipynb', { button: 'right' });
     await page.hover('text=Copy Shareable Link');
 
-    const itemHandle = await page.$('text=Copy Shareable Link');
+    const itemLocator = page.locator('text=Copy Shareable Link');
 
     // Inject mouse
     await page.evaluate(
       ([mouse]) => {
         document.body.insertAdjacentHTML('beforeend', mouse);
       },
-      [await positionMouseOver(itemHandle, { top: 0.5, left: 0.55 })]
+      [await positionMouseOver(itemLocator, { top: 0.5, left: 0.55 })]
     );
 
     expect(
@@ -376,7 +385,7 @@ test.describe('General', () => {
       }`
     });
 
-    await setSidebarWidth(page);
+    await page.sidebar.setWidth();
 
     // Open jupyterlab.md
     await page.dblclick(
@@ -403,7 +412,7 @@ test.describe('General', () => {
       }`
     });
 
-    await setSidebarWidth(page);
+    await page.sidebar.setWidth();
 
     // Open Data.ipynb
     await page.dblclick(
@@ -453,8 +462,7 @@ test.describe('General', () => {
     const trustPromise = page.evaluate(() => {
       return window.jupyterapp.commands.execute('notebook:trust');
     });
-    const dialogSelector = '.jp-Dialog-content';
-    await page.waitForSelector(dialogSelector);
+    await page.locator('.jp-Dialog-content').waitFor();
     // Accept option to trust the notebook
     await page.click('.jp-Dialog-button.jp-mod-accept');
     // Wait until dialog is gone
@@ -467,7 +475,7 @@ test.describe('General', () => {
 
   test('Heading anchor', async ({ page }, testInfo) => {
     await page.goto();
-    await setSidebarWidth(page);
+    await page.sidebar.setWidth();
 
     // Open Data.ipynb
     await page.dblclick(
@@ -475,14 +483,15 @@ test.describe('General', () => {
     );
     await page.dblclick('text=Data.ipynb');
 
-    const heading = await page.waitForSelector(
-      'h2[id="Open-a-CSV-file-using-Pandas"]'
-    );
-    const anchor = await heading.$('text=¶');
+    const heading = page.locator('h2[id="Open-a-CSV-file-using-Pandas"]');
+    await heading.waitFor();
+    const anchor = heading.locator('text=¶');
     await heading.hover();
 
     // Get parent cell which includes the heading
-    const cell = await heading.evaluateHandle(node => node.closest('.jp-Cell'));
+    const cell = await heading.evaluateHandle((node: HTMLElement) =>
+      node.closest('.jp-Cell')
+    );
 
     // Inject mouse
     await page.evaluate(
@@ -498,7 +507,7 @@ test.describe('General', () => {
       ]
     );
 
-    expect(await cell.screenshot()).toMatchSnapshot(
+    expect(await cell!.screenshot()).toMatchSnapshot(
       'notebook_heading_anchor_link.png'
     );
   });
@@ -517,7 +526,7 @@ test.describe('General', () => {
       }`
     });
 
-    await setSidebarWidth(page);
+    await page.sidebar.setWidth();
 
     // Open Data.ipynb
     await page.dblclick(
@@ -531,7 +540,7 @@ test.describe('General', () => {
     await page.click('#jp-mainmenu-file-new >> text=Terminal');
 
     // Wait for the xterm.js element to be added in the DOM
-    await page.waitForSelector('.jp-Terminal-body');
+    await page.locator('.jp-Terminal-body').waitFor();
 
     await page.keyboard.type('cd $JUPYTERLAB_GALATA_ROOT_DIR');
     await page.keyboard.press('Enter');
@@ -552,7 +561,7 @@ test.describe('General', () => {
       }`
     });
 
-    await setSidebarWidth(page);
+    await page.sidebar.setWidth();
 
     // Open a terminal
     await page.click('text=File');
@@ -567,15 +576,40 @@ test.describe('General', () => {
 
     await page.click('[title="Running Terminals and Kernels"]');
 
-    await expect(
-      page.locator(
-        '.jp-RunningSessions-item.jp-mod-kernel >> text="Python 3 (ipykernel)"'
-      )
-    ).toHaveCount(2);
+    // Wait up to 5s for both kernels to startup
+    await expect
+      .soft(page.locator('.jp-RunningSessions-item.jp-mod-kernel'))
+      .toHaveCount(2, { timeout: 5000 });
 
-    expect(
-      await page.screenshot({ clip: { y: 27, x: 0, width: 283, height: 400 } })
-    ).toMatchSnapshot('running_layout.png');
+    const sessionsSidebar = page.locator('.jp-SidePanel.jp-RunningSessions');
+    const mockedKernelIds = {
+      'Data.ipynb': 'abcd1234',
+      'Julia.ipynb': 'wxyz5678'
+    };
+
+    await freeezeKernelIds(sessionsSidebar, mockedKernelIds);
+
+    expect
+      .soft(
+        await page.screenshot({
+          clip: { y: 27, x: 0, width: 283, height: 400 }
+        })
+      )
+      .toMatchSnapshot('running_layout.png');
+
+    await page.click('jp-button[data-command="running:show-modal"]');
+
+    // Playwright uses shadow-piercing selectors so this works with webcomponents too
+    await expect
+      .soft(page.locator('.jp-SearchableSessions-modal input'))
+      .toBeFocused();
+
+    const dialog = page.locator(
+      '.jp-SearchableSessions-modal .jp-Dialog-content'
+    );
+    await freeezeKernelIds(dialog, mockedKernelIds);
+
+    expect(await dialog.screenshot()).toMatchSnapshot('running_modal.png');
   });
 
   test('Command Palette', async ({ page }) => {
@@ -584,7 +618,7 @@ test.describe('General', () => {
     await page.keyboard.press('Control+Shift+C');
 
     expect(
-      await (await page.$('#modal-command-palette')).screenshot()
+      await page.locator('#modal-command-palette').screenshot()
     ).toMatchSnapshot('command_palette.png');
   });
 
@@ -593,6 +627,9 @@ test.describe('General', () => {
 
     await page.notebook.createNew();
 
+    // Ensure focus on a cell
+    await page.notebook.enterCellEditingMode(0);
+
     await page.keyboard.press('Control+Shift+H');
 
     expect(await page.locator('.jp-Notebook').screenshot()).toMatchSnapshot(
@@ -608,7 +645,7 @@ test.describe('General', () => {
       }`
     });
 
-    await setSidebarWidth(page);
+    await page.sidebar.setWidth();
 
     await page.dblclick('[aria-label="File Browser Section"] >> text=data');
     await page.click('text=README.md', {
@@ -624,11 +661,6 @@ test.describe('General', () => {
 
   test('HTML Display', async ({ page, tmpPath }) => {
     await page.goto(`tree/${tmpPath}`);
-    await page.addStyleTag({
-      content: `.jp-LabShell.jp-mod-devMode {
-        border-top: none;
-      }`
-    });
 
     // Hide file browser
     await page.click('[title^="File Browser"]');
@@ -649,22 +681,21 @@ test.describe('General', () => {
 
     await page.click('.jp-CodeConsole-input >> .cm-content');
     await page.keyboard.type(
-      "from IPython.display import display, HTML\ndisplay(HTML('<h1>Hello World</h1>'))"
+      "from IPython.display import display, HTML\ndisplay(HTML('<h1>Hello World</h1>'))",
+      {
+        delay: 0
+      }
     );
     await page.keyboard.press('Shift+Enter');
 
-    expect(await page.screenshot()).toMatchSnapshot(
+    const main = page.getByRole('main');
+    expect(await main.screenshot()).toMatchSnapshot(
       'file_formats_html_display.png'
     );
   });
 
   test('Altair', async ({ page, tmpPath }) => {
     await page.goto(`tree/${tmpPath}`);
-    await page.addStyleTag({
-      content: `.jp-LabShell.jp-mod-devMode {
-        border-top: none;
-      }`
-    });
 
     // Hide file browser
     await page.click('[title^="File Browser"]');
@@ -679,10 +710,12 @@ test.describe('General', () => {
     await page.notebook.run();
 
     // Need to wait for altair to update the canvas
-    await page.waitForSelector('summary');
+    await page.locator('summary').waitFor();
+
+    const main = page.getByRole('main');
 
     // The menu button '...' color of Altair is flaky increase threshold tolerance
-    expect(await page.screenshot()).toMatchSnapshot('file_formats_altair.png', {
+    expect(await main.screenshot()).toMatchSnapshot('file_formats_altair.png', {
       threshold: 0.3
     });
   });
