@@ -181,30 +181,29 @@ test.describe('Notebook scroll on execution (with windowing)', () => {
   test('should scroll when advancing if top is only marginally visible', async ({
     page
   }) => {
-    const notebook = await page.notebook.getNotebookInPanel();
-    const thirdCell = await page.notebook.getCell(2);
+    const notebook = await page.notebook.getNotebookInPanelLocator();
+    const thirdCell = await page.notebook.getCellLocator(2);
 
-    await positionCellPartiallyBelowViewport(page, notebook, thirdCell, 0.01);
+    await positionCellPartiallyBelowViewport(page, notebook!, thirdCell!, 0.01);
     // Select second cell
     await page.notebook.selectCells(1);
 
-    const thirdCellLocator = page.locator(
-      '.jp-Cell[data-windowed-list-index="2"]'
-    );
     // The third cell should be positioned at the bottom, revealing between 0 to 2% of its content.
-    await expect(thirdCellLocator).toBeInViewport({ ratio: 0.0 });
-    await expect(thirdCellLocator).not.toBeInViewport({ ratio: 0.02 });
+    await expect(thirdCell!).toBeInViewport({ ratio: 0.0 });
+    await expect(thirdCell!).not.toBeInViewport({ ratio: 0.02 });
     // Only a small fraction of notebook viewport should be taken up by that cell
-    expect(await notebookViewportRatio(notebook, thirdCell)).toBeLessThan(0.1);
+    expect(await notebookViewportRatio(notebook!, thirdCell!)).toBeLessThan(
+      0.1
+    );
 
     // Run second cell
     await page.notebook.runCell(1);
 
     // After running the second cell, the third cell should be revealed, in at least 10%
-    await expect(thirdCellLocator).toBeInViewport({ ratio: 0.1 });
+    await expect(thirdCell!).toBeInViewport({ ratio: 0.1 });
 
     // The third cell should now occupy about half of the notebook viewport
-    expect(await notebookViewportRatio(notebook, thirdCell)).toBeGreaterThan(
+    expect(await notebookViewportRatio(notebook!, thirdCell!)).toBeGreaterThan(
       0.4
     );
   });
@@ -212,53 +211,47 @@ test.describe('Notebook scroll on execution (with windowing)', () => {
   test('should not scroll when advancing if top is non-marginally visible', async ({
     page
   }) => {
-    const notebook = await page.notebook.getNotebookInPanel();
-    const thirdCell = await page.notebook.getCell(2);
+    const notebook = await page.notebook.getNotebookInPanelLocator();
+    const thirdCell = await page.notebook.getCellLocator(2);
 
-    await positionCellPartiallyBelowViewport(page, notebook, thirdCell, 0.15);
+    await positionCellPartiallyBelowViewport(page, notebook!, thirdCell!, 0.15);
     // Select second cell
     await page.notebook.selectCells(1);
 
-    const thirdCellLocator = page.locator(
-      '.jp-Cell[data-windowed-list-index="2"]'
-    );
     // The third cell should be positioned at the bottom, revealing between 10 to 20% of its content.
-    await expect(thirdCellLocator).toBeInViewport({ ratio: 0.1 });
-    await expect(thirdCellLocator).not.toBeInViewport({ ratio: 0.2 });
+    await expect(thirdCell!).toBeInViewport({ ratio: 0.1 });
+    await expect(thirdCell!).not.toBeInViewport({ ratio: 0.2 });
     // This cell should initially take up between 30% and 50% of the notebook viewport
-    let spaceTaken = await notebookViewportRatio(notebook, thirdCell);
+    let spaceTaken = await notebookViewportRatio(notebook!, thirdCell!);
     expect(spaceTaken).toBeGreaterThan(0.3);
     expect(spaceTaken).toBeLessThan(0.5);
 
     // Run second cell
     await page.notebook.runCell(1);
     // After running the second cell, the third cell should not be scrolled
-    await expect(thirdCellLocator).not.toBeInViewport({ ratio: 0.2 });
+    await expect(thirdCell!).not.toBeInViewport({ ratio: 0.2 });
     // The cell should still take up between 30% and 50% of the notebook viewport
-    spaceTaken = await notebookViewportRatio(notebook, thirdCell);
+    spaceTaken = await notebookViewportRatio(notebook!, thirdCell!);
     expect(spaceTaken).toBeGreaterThan(0.3);
     expect(spaceTaken).toBeLessThan(0.5);
   });
 
   test('should not scroll when running in-place', async ({ page }) => {
-    const notebook = await page.notebook.getNotebookInPanel();
-    const thirdCell = await page.notebook.getCell(2);
+    const notebook = await page.notebook.getNotebookInPanelLocator();
+    const thirdCell = await page.notebook.getCellLocator(2);
 
-    await positionCellPartiallyBelowViewport(page, notebook, thirdCell, 0.15);
+    await positionCellPartiallyBelowViewport(page, notebook!, thirdCell!, 0.15);
     // Select third cell
     await page.notebook.enterCellEditingMode(2);
 
-    const thirdCellLocator = page.locator(
-      '.jp-Cell[data-windowed-list-index="2"]'
-    );
     // The third cell should be positioned at the bottom, revealing between 10 to 20% of its content.
-    await expect(thirdCellLocator).toBeInViewport({ ratio: 0.1 });
-    await expect(thirdCellLocator).not.toBeInViewport({ ratio: 0.2 });
+    await expect(thirdCell!).toBeInViewport({ ratio: 0.1 });
+    await expect(thirdCell!).not.toBeInViewport({ ratio: 0.2 });
 
     // Run third cell in-place
     await page.notebook.runCell(2, true);
     // After running the third cell it should not be scrolled
-    await expect(thirdCellLocator).not.toBeInViewport({ ratio: 0.2 });
+    await expect(thirdCell!).not.toBeInViewport({ ratio: 0.2 });
 
     // The galata implementation of `page.notebook.runCell(2, true);`
     // first switches to command mode before cell execution,
@@ -266,7 +259,7 @@ test.describe('Notebook scroll on execution (with windowing)', () => {
     await page.keyboard.press('Control+Enter');
 
     // After running the third cell it should not be scrolled
-    await expect(thirdCellLocator).not.toBeInViewport({ ratio: 0.2 });
+    await expect(thirdCell!).not.toBeInViewport({ ratio: 0.2 });
   });
 });
 
@@ -302,8 +295,8 @@ test.describe('Notebook scroll over long outputs (with windowing)', () => {
     await renderedMarkdownLocator.waitFor({ state: 'hidden', timeout: 100 });
 
     // Scroll to the last cell
-    const lastCell = await page.notebook.getCell(10);
-    await lastCell.scrollIntoViewIfNeeded();
+    const lastCell = await page.notebook.getCellLocator(10);
+    await lastCell!.scrollIntoViewIfNeeded();
 
     // Get the outer window
     const outer = page.locator('.jp-WindowedPanel-outer');
