@@ -250,3 +250,124 @@ test('Opening Keyboard Shortcuts settings does not mangle user shortcuts', async
     .count();
   expect(userPanelLines).toBeLessThan(10);
 });
+
+test('Keyboard Shortcuts: overwriting a shortcut can be cancelled', async ({
+  page
+}) => {
+  // Settings are wide, hide the sidebar to increase available space
+  await page.sidebar.close();
+
+  await page.evaluate(async () => {
+    await window.jupyterapp.commands.execute('settingeditor:open', {
+      query: 'Keyboard Shortcuts'
+    });
+  });
+
+  const shortcutsForm = page.locator('.jp-Shortcuts-ShortcutUI');
+  const filterInput = shortcutsForm.locator('jp-search.jp-FilterBox');
+  await filterInput.locator('input').fill('merge cell below');
+
+  const addShortcutButton = shortcutsForm.locator('.jp-Shortcuts-Plus');
+  await expect(addShortcutButton).toHaveCount(1);
+
+  const conflict = shortcutsForm.locator('.jp-Shortcuts-Conflict');
+  await expect(conflict).toHaveCount(0);
+
+  await addShortcutButton.click();
+
+  const newShortcutInput = shortcutsForm.locator('.jp-Shortcuts-InputBoxNew');
+  await newShortcutInput.press('Shift+M');
+
+  await expect(conflict).toHaveCount(1);
+
+  expect(await conflict.screenshot()).toMatchSnapshot(
+    'settings-shortcuts-conflict.png'
+  );
+  const cancelButton = conflict.locator('button >> text=Cancel');
+  await cancelButton.click();
+
+  await expect(conflict).toHaveCount(0);
+});
+
+test('Keyboard Shortcuts: validate "Or" button behavior when editing shortcuts', async ({
+  page
+}) => {
+  await page.evaluate(async () => {
+    await window.jupyterapp.commands.execute('settingeditor:open', {
+      query: 'Keyboard Shortcuts'
+    });
+  });
+
+  const shortcutsForm = page.locator('.jp-Shortcuts-ShortcutUI');
+  const filterInput = shortcutsForm.locator('jp-search.jp-FilterBox');
+  await filterInput.locator('input').fill('merge cell below');
+
+  const shortcutsContainer = page.locator(
+    '.jp-Shortcuts-ShortcutListContainer'
+  );
+  const firstRow = shortcutsContainer.locator('.jp-Shortcuts-Row').first();
+
+  const shortcutKey = firstRow.locator('.jp-Shortcuts-ShortcutKeys').first();
+  await shortcutKey.click();
+  await page.waitForTimeout(300);
+  await firstRow.hover();
+  expect(await firstRow.screenshot()).toMatchSnapshot(
+    'settings-shortcuts-edit.png'
+  );
+});
+
+test('Settings Changes Are Reflected in Form Editor"', async ({ page }) => {
+  await page.evaluate(async () => {
+    await window.jupyterapp.commands.execute('settingeditor:open', {
+      query: 'Theme'
+    });
+  });
+  await page.menu.clickMenuItem('Settings>Theme>Theme Scrollbars');
+  await expect(
+    page.locator(
+      '#jp-SettingsEditor-\\@jupyterlab\\/apputils-extension\\:themes_theme-scrollbars'
+    )
+  ).toBeChecked();
+});
+
+test('Ensure that fuzzy filter works properly', async ({ page }) => {
+  // Helper function to rename a notebook
+  const renameFile = async (oldName: string, newName: string) => {
+    await page
+      .locator(`.jp-DirListing-itemName:has-text("${oldName}")`)
+      .click();
+    await page.keyboard.press('F2');
+    await page.keyboard.type(newName);
+    await page.keyboard.press('Enter');
+  };
+
+  // Create and rename the first file
+  await page.menu.clickMenuItem('File>New>Text File');
+  await renameFile('untitled.txt', 'test');
+
+  // Create and rename the second file
+  await page.menu.clickMenuItem('File>New>Text File');
+  await renameFile('untitled.txt', 'tst');
+
+  // Enable file filter and apply a filter for "tst"
+  await page.evaluate(() =>
+    window.jupyterapp.commands.execute('filebrowser:toggle-file-filter')
+  );
+  await page.locator('input[placeholder="Filter files by name"]').fill('tst');
+
+  // Both files should be visible
+  await expect(page.locator('.jp-DirListing-item')).toHaveCount(2);
+
+  // Change fuzzy filter setting
+  await page.evaluate(() =>
+    window.jupyterapp.commands.execute('settingeditor:open', {
+      query: 'File Browser'
+    })
+  );
+  await page
+    .locator('label:has-text("Filter on file name with a fuzzy search")')
+    .click();
+
+  // Only one file should be visible
+  await expect(page.locator('.jp-DirListing-item')).toHaveCount(1);
+});
